@@ -12,6 +12,7 @@
 
 #include <algorithm>
 #include <array>
+#include <cctype>
 
 #include "eckit/types/Date.h"
 #include "eckit/utils/StringTools.h"
@@ -127,11 +128,13 @@ TypeDate::TypeDate(const std::string& name, const eckit::Value& settings) : Type
 
 void TypeDate::pass2(const MarsExpandContext& ctx, MarsRequest& request) {
     std::vector<std::string> values = request.values(name_, true);
-    Type::expand(ctx, values, request);
-    request.setValuesTyped(this, values);
+    if (values.size() == 1 && values[0] == "-1") {
+        Type::expand(ctx, values, request);
+        request.setValuesTyped(this, values);
+    }
 }
 
-bool TypeDate::expand(const MarsExpandContext& ctx, std::string& value, const MarsRequest& /* request */) const {
+bool TypeDate::expand(const MarsExpandContext&, std::string& value, const MarsRequest&) const {
     if (!value.empty()) {
         eckit::Translator<std::string, long> s2l;
         eckit::Translator<long, std::string> l2s;
@@ -152,11 +155,9 @@ bool TypeDate::expand(const MarsExpandContext& ctx, std::string& value, const Ma
                     value = l2s(d.yyyymmdd());
                 }
                 else {  // month-day (i.e. TypeClimateDaily)
-
                     std::string m = month(tokens[0]);
                     long d        = s2l(tokens[1]);
-
-                    value = m + "-" + l2s(d);
+                    value         = m + "-" + l2s(d);
                 }
             }
             else {
